@@ -459,7 +459,6 @@ def pingmysql(original_function):
                 self.columns_dict = {}
                 sql = "select TABLE_SCHEMA,TABLE_NAME,COLUMN_NAME,DATA_TYPE from information_schema.columns where 1 =1 and TABLE_SCHEMA not in ('information_schema','performance_schema','mysql','sys') "
                 cursor.execute(sql)
-                rows = []
                 for row in cursor:
                     table_schema = row.get("TABLE_SCHEMA")
                     table_name = row.get("TABLE_NAME")
@@ -478,7 +477,7 @@ def pingmysql(original_function):
 class Mysql():
 
     def __init__(self, configuraion_file=configuration_file, section="mysql"):
-        self.default_dabase_name = ''
+        self.default_database_name = ''
         self.database = None
         self.columns_dict = None
         try:
@@ -488,11 +487,10 @@ class Mysql():
             port = int(config.get(section, "port"))
             user = config.get(section, "user")
             password = config.get(section, "passwd")
-            database_str = config.get(section, "database")
-            self.default_dabase_name = database_str
+            self.default_database_name = config.get(section, "database")
             charset = config.get(section, "charset")
 
-            self.database = pymysql.connect(host=host, port=port, user=user, passwd=password, db=database_str,
+            self.database = pymysql.connect(host=host, port=port, user=user, passwd=password, db=self.default_database_name,
                                             charset=charset, autocommit=True,
                                             cursorclass=pymysql.cursors.DictCursor)
 
@@ -503,17 +501,25 @@ class Mysql():
             traceback.print_exc()
 
     def is_legal_value(self, table_name, column_name, val):
+        if val is None:
+            return True
         if "." not in table_name:
-            table_name = "{}.{}".format(self.default_dabase_name, table_name)
+            table_name = "{}.{}".format(self.default_database_name, table_name)
         col_name = "{}.{}".format(table_name, column_name)
         if self.columns_dict is None:
             return True
         row = self.columns_dict.get(col_name)
         data_type = row.get("DATA_TYPE")
         if data_type in ['int', 'tinyint', 'bigint']:
-            if len(val.strip()) == 0:
+            str_val = str(val)
+            if len(str_val) == 0:
                 logger.warning("{} {} is not a valid {}".format(column_name, val, data_type))
                 return False
+            elif str_val.startswith("-") or str_val.startswith("+"):
+                unsigned_number = str_val[1:]
+                if not unsigned_number.isnumeric():
+                    raise Exception("{} {} is not a wrong {}".format(column_name, val, data_type))
+                    return False
             elif not str(val).isnumeric():
                 logger.error("{} {} is not a wrong {}".format(column_name, val, data_type))
                 raise Exception("{} {} is not a wrong {}".format(column_name, val, data_type))
@@ -558,7 +564,7 @@ class Mysql():
         id = ""
         for key in dic.keys():
             val = dic[key]
-            if self.is_legal_value(tableName, key, val):
+            if val is not None and self.is_legal_value(tableName, key, val):
                 cols.append(key)
                 placeholders.append("%s")
                 vals.append(val)
